==> regrex-0.3.tar.gz: regrex-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'regrex',         # How you named your package folder (MyLib)
  packages = ['regrex'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'regrex made easy with regrex !',   # Give a short description about your library
  author = 'rushan7750',                   # Type in your name
  author_email = 'shanrsjmax@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/rushan7750/regress',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/rushan7750/regress/archive/0.3.tar.gz',    # I explain this later on
  keywords = ['regress', 'simple', 'regrex'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'scikit-learn',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> regrex-0.7.tar.gz: regrex-0.7/setup.py <==
from distutils.core import setup
setup(
  name = 'regrex',         # How you named your package folder 
  packages = ['regrex'],   # Chose the same as "name"
  version = '0.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'regression made easy with regrex !',   # Give a short description about your library
  author = 'rushan7750',                   # Type in your name
  author_email = 'shanrsjmax@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/rushan7750/regress',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/rushan7750/regress/archive/0.7.tar.gz',    # I explain this later on
  keywords = ['regress', 'simple', 'regrex'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'scikit-learn',
          'colorama',
          'termcolor'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
